### MS TITLE:  Environmental harshness does not affect the propensity for social learning in Great tits, Parus major ####
### Content:  importing and evaluating individual activity levels ###
### Author: Emil Isaksson, Julie Morand-Ferron, Alexis Chaine

library(tidyverse) #
library(lubridate) #handling time values
library(lme4) #performing mixed effect models
library(lmerTest) #added tests for mixed effects models
library(DHARMa) #model diagnostics
library(rptR) #for repeatability testing

act<- read_csv('act_pm.csv') 

#The analyses in this document is to asses the activity levels of individuals use in my project on elevation related differences in social learning.
#### Data description and handling ####
# The data contain 9 variables:
#   
# - ID: Identification number of the tested individual
# - day: day since individual was capture, how long the individual had been in the aviary
# - time.obs: time of day (24hrs clock) when the number of movements was counted
# - movements: number of movements bigger than 1 body length performed by an individual during a three minute period. Flying from one location to another= 1 movement. When jumping on the ground or climbing the wall/ceiling, one continuous movement greater than 2 body lengths was still only counted as 1 movement. Birds had to stop for another movement to be counted. 
# - test: whether the bird was tested as "control" or as "social learner".
# - month.nb: what month the activity measure was taken (1=Sep....6= March)
# - batch: which batch the bird belonged to (1-3 from season 1; 4-5 from season 2)
# - act_date: date when the activity measure was taken
# - AM_PM: whether the measurement was taken in the morning (AM) or the afternoon (PM)
# - Person: the person who scored activity

## adding the number of seconds since midnight as variable
act <- act%>%
  mutate(tofd=as.POSIXct(strptime(act$time.obs, "%H:%M")),
         s_midn =hour(tofd)*3600+minute(tofd)*60+second(tofd))
#hist(act$tofd, breaks = 30) #distribution of when measurements were taken in the afternoon

### Rescaling movements

# mean center and re-scale
act$movements_sc<-as.vector(scale(act$movements)) # Rescaling the variable creates a matrix object. Making it a vector for model check with DHARMa
#hist(act$movements_sc) #distribution approaching Gaussian. Centered around mean activity level across individuals. Negative=less active than average, positive=more active than average.  

### Rescaling seconds since midnight
act$s_midn_sc<- as.vector(scale(act$s_midn))

### LMM for activity level ####
act_mod<- lmer(movements_sc~s_midn_sc+(1|ID)+(1|Person)+(1|batch), data=act)

#### Model diagnostic with DHARMa 

# Residuals vs fitted
simulation_act_mod <- simulateResiduals(fittedModel = act_mod, n=1000)
plot(simulation_act_mod) # QQ plot with included tests (Kolmogorv-Smirnov, dispersion, outlier) show no indication of deviation from Gaussian distribution or other violations of assumptions. 

# separate dispersion test
testDispersion(act_mod) # non-sig -> no indication of overdispersion


#### Summary output of LMM for activity level ####
summary(act_mod) # 

# random effect comparison
ranova(act_mod) #

# ### Repeatability of activity level ####
rep_act_mod <- rptGaussian(movements_sc~s_midn_sc+(1|ID)+(1|Person)+(1|batch), grname = c("ID", "Person", "batch"), data=act, CI=0.95, nboot=1000) #

#### Repeatability model output
rep_act_mod  # ID show low but significant repeatability


# Plots of repeatability iterations and estimate for each random effect
 # Horizontal line above the bar graph show the repeatability measure (blue dot) and spread indicate 95%CI. 
# par(mfrow=c(1,3))
# plot(rep_act_mod, grname = "ID", type = "boot", cex.main = 0.8) #
# plot(rep_act_mod, grname = "Person", type = "boot", cex.main = 0.8) #
# plot(rep_act_mod, grname = "batch", type = "boot", cex.main = 0.8)
#par(mfrow=c(1,1)) #reset plot window


# Activity script output ####
### Condensing dataset for activity levels to be merged with the social learning dataset
act_extract <- data.frame()
act_extract<-act %>%
group_by(ID,batch) %>%
dplyr::summarise(mean_movements_sc=mean(movements_sc), mean_movements=mean(movements))

act_extract <- act_extract %>%
dplyr::rename(
obs.ID = ID)
write_csv(act_extract, "act_extractMS.csv") # Writing the dataframe as ".csv" for import in main analysis script
