# MS TITLE:  Environmental harshness does not affect the propensity for social learning in Great tits, Parus major
# Content: Descriptive analysis and Control test ###
# Author: Emil Isaksson, Julie Morand-Ferron, Alexis Chaine

# Packages used ####
library(tidyverse) #facilitate data management. Also contain the "ggplot2" package used to create plots
library(lubridate) #facilitate handling of dates and times
library(ggpubr) #adding options to ggplots
library(lme4) #performing mixed effect models
library(lmerTest) #added tests for mixed effects models
library(DHARMa) #used to test assumptions of mixed effect models
library(broom.mixed) #comparing mix model fits with different optimizers
library(NBZIMM) # for running zero inflated negative binomal glmm. Requires package MASS to be loaded (loaded via the lme4 package)
library(sjPlot) # for tables

# Load data ####
slearn<-read_csv('soc_learn_harsh.csv')#, header = TRUE, na.strings = "#N/A"
#str(slearn)
# dim(slearn) # 108 observation (40 observers + 14 control individuals tested in two tasks = 108 observations), 21 cols
# Add batch number from the activity score

## Data description and handling ####
# -   obs.ID: identification number for individual observers
# -   elev.: if the individual is from a **high** or **low** elevation site
# -   sex: male(M)/female(F)
# -   age: if the individual is 1st year (juvenile), **"1a"/"1a?"**, or 2nd year up (adult), **"+1a"/"+1a?"**. "?" denote uncertain but most likely age category.
# -   test: if the bird was tested as control (Cont) or observing a demonstrator (Soc)
# -   seas: season **1** or **2**
# -   task: **pompom** or **leaf** task
# -   task.n: pompom = **1** and leaf=**2** (the numerical of task)
# -   test.date: date of social learning test
# -   start.time: time when the social learning test was started (first motivation trial)
# -   trials.to.samp.old: number of trials until sampling, with 5 failed trials getting a ceiling value of 6
# -   sampled: **RESPONSE VARIABLE**, if an individual sampled the test board or not during its trials. 1=yes , 0=no.
# -   tot.samps: total number of samplings made by an individual
# -   corr.samp: number of correct samplings
# -   perched: **RESPONSE VARIABLE**, if an individual perched on/within one body length of the test board during its trials. 1=yes , 0=no.
# -   sec.perch(1-5): number of seconds within a trial (1-5) until the bird perched. Max 301s/trial. NA values for trials following a trial in which a bird sampled the board, which meant no more trials for the bird. 
# -   sec.1samp: the number of seconds until the bird sampled within the trial that it sampled (max 301)

## Descriptive table of participating individuals ####
# Number of Males and females in each of the control and social observer groups divided by habitat
slearn%>%
  group_by(test,elev.,sex)%>%
  dplyr::summarise(nb_ind=n()/2, .groups = "drop")



# Adding variables for further analysis ####
## Adding individual activity level
act_mean<- read_csv("act_extractMS.csv")

# Merging activity level data with main dataset
slearn1<- left_join(slearn,act_mean)
# The variable "mean_movements_sc" are mean centered and scaled version of the count of number of movements made by the individual (variable "mean_movement"). Another column was added with a numerical value corresponding to each individual. 

### Age distribution between high and low elevation ####
#Juveniles are the most common age group in the low elevation group, whereas juveniles and adults are equally common (50-55% juveniles) in the high elevation group.
elev_age<- slearn1 %>%
  group_by(elev.,age) %>%
  dplyr::summarise(nb_ind=n()/2, .groups = "drop") #divide by 2 because each individual is recorded twice (once/task)
#elev_age <- the output of this is described in the main text under Methods

#### Placing individuals of uncertain age in their most likely age bracket to facilitate analysis ####
slearn1$age_adjust <- slearn1$age #create empty column to put values
slearn1$age_adjust <-replace(slearn1$age_adjust,slearn1$age_adjust=="1a?", "1a") #replace the values, functionally transferring the uncertain age value in to its most likely age category.
slearn1$age_adjust <-replace(slearn1$age_adjust,slearn1$age_adjust=="+1a?", "+1a")
# levels(as.factor(slearn1$age_adjust)) #only two age categories left


### Converting times and dates to the appropriate formats ####
#Getting "start.time" as seconds since midnight as raw seconds and as scaled:
# Creating a "time-of-day" variable to use in further conversion. 
slearn1 <- slearn1%>%mutate(soc_s_midn=as.numeric(seconds(start.time)),
                            soc_s_midn_sc=scale(soc_s_midn)) #scale:center = 44936 (about 12.30); scale:scale = 8159 (negative values=morning, positive values=afternoon, 0~mid-day)


#Getting "test.date" as "Date"-format:
slearn1$soc_date<- as.Date(slearn1$test.date, format="%Y-%m-%d")
#Getting test date as "days since start of season". Start defined as OCT 1 each year (2019 for season 1, and 2020 for season 2) because it was well before any captures took place.
slearn1$start_seas[slearn1$seas=="1"]<- as.character("2019-10-01") #creating new column and pasting start dates in the new column
slearn1$start_seas[slearn1$seas=="2"]<- as.character("2020-10-01")
slearn1$start_seas<-as.Date(slearn1$start_seas,format="%Y-%m-%d")
slearn1$seas_days <- as.numeric(difftime(slearn1$soc_date, slearn1$start_seas, units = "days")) # count days since start of the season
# mean centre and scaling "seas_days"
slearn1 <- slearn1%>%mutate(seas_days_sc=scale(seas_days)) #scale:center=85.5, scale:scale=39.7. 


##### Adding Latency to Perch and Latency to Sample ####
# These variables are used for survival analysis
# These variables are response variables in the survival models
##### Latency to Perch ####
# Extracting the time from the start of the first trial until the first perching event across trials for an individual. Each trial was given a max of 5 minutes, and if an individual failed the trial, it was given a score of 5 minutes and 1 seconds. 

# replace NA's with 0's in "slearn1$sec.perch*" for the loop below to not return NA's when adding values. These lines only needs to be run after first time loading the data and will not work if the NA's has already been replaced by this code. 
slearn1 <- slearn1%>%mutate(across(sec.perch1:sec.perch5, ~replace_na(.x,0)))
# slearn1%>%dplyr::select("sec.perch1":"sec.perch5")%>%summary() #no NAs


#Loop to get the total number of seconds until first perch by birds over trials
slearn1$lat_perch<- as.numeric(rep(NA)) #creating empty column in the main dataset where the extracted numbers will go after running the loop 
for (i in 1:nrow(slearn1)){
  aa<- if (slearn1$sec.perch1[i] < 301) {
    aa = slearn1$sec.perch1[i]
  } 
  else if ((slearn1$sec.perch1[i] + slearn1$sec.perch2[i])<602) {
    aa = (slearn1$sec.perch1[i] + slearn1$sec.perch2[i])
  } 
  else if ((slearn1$sec.perch1[i] + slearn1$sec.perch2[i] + slearn1$sec.perch3[i])<903) {
    aa = (slearn1$sec.perch1[i] + slearn1$sec.perch2[i] + slearn1$sec.perch3[i])
  } 
  else if ((slearn1$sec.perch1[i] + slearn1$sec.perch2[i] + slearn1$sec.perch3[i] + slearn1$sec.perch4[i])<1204) {
    aa = (slearn1$sec.perch1[i] + slearn1$sec.perch2[i] + slearn1$sec.perch3[i] + slearn1$sec.perch4[i])
  } 
  else if ((slearn1$sec.perch1[i] + slearn1$sec.perch2[i] + slearn1$sec.perch3[i] + slearn1$sec.perch4[i] + slearn1$sec.perch5[i])<=1505) {
    aa = (slearn1$sec.perch1[i] + slearn1$sec.perch2[i] + slearn1$sec.perch3[i] + slearn1$sec.perch4[i] + slearn1$sec.perch5[i])
  }
  slearn1$lat_perch[i]<-aa
}
#Function of loop: 
##for each row in dataset "slearn1"
##if the value in indexed column is less than 5.01 min (301 seconds) then aa is the value of that column....
##... otherwise check if next column is less than 10.02 min (602 seconds) and keep value if it is otherwise move on to next step.... etc..
## finally placing the value in the correct column


##### Latency to Sample ####
slearn1 <- slearn1%>%mutate(sec.1samp2=as.numeric(sec.1samp),
                            sec.1samp2=replace_na(sec.1samp2,0),
                            lat_samp=301*(trials.to.samp.old.-1)+sec.1samp2) #gives warning that NAs were introduced by coercion; it is Ok. Calculation is: 301*"nb. of failed trials prior to a successfull trial"+ seconds until sample in the successful trial. The -1 is added to accurately match the trial of success to the latency to success.Without adjustment, failed individuals would have 6 trials as max which = 1806 seconds, which was not tested.

slearn1$lat_samp<1506 # check so the values are ok. 3 are still NA, as expected. None should be over 1505. 

################################################.
# Information of observations ####

#### Batch composition information ####
batch_composition_obs <- slearn1%>%filter(!(task=="leaf"), test=="Soc")%>%
  group_by(batch, elev., sex, age_adjust)%>%
  tally()%>%
  mutate(age_adj_ez = if_else(age_adjust=="1a", "Juvenile", "Adult"),
         sex_rename = if_else(sex=="M", "Male", "Female"),
         elevation= if_else(elev.=="high", "High", "Low"))%>% 
  ungroup()
batch_composition_cont <- slearn1%>%filter(!(task=="leaf"), test=="Cont")%>%
  group_by(batch, elev., sex, age_adjust)%>%
  tally()%>%
  mutate(age_adj_ez = if_else(age_adjust=="1a", "Juvenile", "Adult"),
         sex_rename = if_else(sex=="M", "Male", "Female"),
         elevation= if_else(elev.=="high", "High", "Low"),
         batch_correct= replace_na(batch,3))%>% # batch numbers are from the activity score data ("act_extractMS.csv"). One individual was not evaluated for activity due to time-constraint and was thus missing from the activity score data. The appropriate batch number for that individual is added here. 
  ungroup()%>%arrange(batch_correct)
##### Table S1, supplemental material ####
tab_dfs(
  list(
    batch_composition_cont %>% select(batch_correct, elevation, sex_rename, age_adj_ez, n),
    batch_composition_obs %>% select(batch, elevation, sex_rename, age_adj_ez, n)
  ),
  col.header = c("Batch", "Elevation", "Sex", "Age", "Nb. individuals"),
  title = c(
    "Table S1.1. Information about the composition of individuals tested as controls in each batch (n=14).",
    "Table S1.2. Information about the composition of individuals tested as observers in each batch (n=40)."
  ),
  file = "./batch_composition_tbls.doc"
)


## Participation rates/ engagement rate, i.e. how many birds interacted with the board and in what way ####
# Participation/engagement in each task plus the number of correct samplings made
# Information given in Table 2 in the main text. 
partici_sum <- slearn1 %>%
  group_by(test, elev., task) %>%
  dplyr::summarise(
    "Total N" = n(),
    "Perched" = sum(perched, na.rm = T),
    "Sampled any item" = sum(sampled, na.rm = T),
    "Sampled >0 Correct" = sum(corr.samp >= 1, na.rm = TRUE),
    "Perching NA" = sum(is.na(perched)),
    "Sampling NA" = sum(is.na(sampled)),
    .groups = "drop"
  )
# partici_sum



### Save the data frame for use in code script for statistical comparison between elevations and individuals ####
slearn1 <- slearn1%>%mutate(soc_s_midn_sc=as.vector(soc_s_midn_sc),
                 seas_days_sc=as.vector(seas_days_sc)) #the scale() function outputs numbers in matrix format which does not work when writing the csv below. This code converts the matrix formatted columns to vectors. 
write_csv(slearn1, "slearn1.csv")
