# MS TITLE:  Environmental harshness does not affect the propensity for social learning in Great tits, Parus major
# Content: Statistical comparison between elevations and individuals (incl; LMM, GLMM, repeatability, survival analyses) 
# Author: Emil Isaksson

library(tidyverse) #facilitate data management. Also contain the "ggplot2" package used to create plots
library(lubridate) #facilitate handling of dates and times
library(ggpubr) #adding options to ggplots
library(lme4) #performing mixed effect models
library(lmerTest) #added tests for mixed effects models
library(broom.mixed) #comparing mix model fits with different optimizers
library(DHARMa) #used to test assumptions of mixed effect models
library(rptR) #repeatability
library(survival) #Base package for survival analysis
library(coxme) #For Cox Mixed-effects survival model 
library(survminer) #Creating survival plots
library(rms) #Has VIF function for survival analysis
library(sjPlot) # Making tables
library(gridExtra) #for grid graphics

# Load data
## Full data including both Observers and Control
slearn_all <- read_csv("slearn1.csv")
# dim(slearn_all)
# str(slearn_all)
## Data with just observers
slearn_obs <- slearn_all%>%filter(!(test=="Cont")) # Data with only the observers used for repeatability and survival analysis
# dim(slearn_obs) # 80 rows. Correct number of observers. 20 individuals per elevation, each tested in 2 tasks = 80 observations. 
# str(slearn_obs)


# Local Enhancement ####
## GLMM for local enhancement ####
# With Observers and Control, including the interaction between test and elevation
perch_glmm<- glmer(perched~elev.*test+task.n+mean_movements_sc+seas_days_sc+sex+age_adjust+(1|obs.ID), family=binomial,data = slearn_all) #model failed to converge

# Comparing model optimizers: 
# test*elevation (perch_glmm)
ab <- allFit(perch_glmm) #running model with different optimizers
glance(ab) %>% dplyr::select(optimizer, AIC, NLL_rel) %>% arrange(NLL_rel) # bobyqa optimizer provides marginally better fit. Not much difference between optimizers.
# rerunning model with bobyqa as optimizer
perch_glmm_b<- glmer(perched~elev.*test+task.n+mean_movements_sc+seas_days_sc+sex+age_adjust+(1|obs.ID), family=binomial,data = slearn_all, glmerControl(optimizer = "bobyqa")) # Model converged -> Continuing with this model


## Model diagnostics
### Residuals vs fitted - observers and control: test*elevation
sim.diag_all_b<-simulateResiduals(fittedModel = perch_glmm_b, n = 1000) #data simulated 1000 times based on model input
plot(sim.diag_all_b) #no issues detected

#### Overdispersion
testDispersion(sim.diag_all_b) #not sig -> no indication of overdispersion # Closer look at the dispersion check - looks good. 

#### Variance inflation factor 
car::vif(perch_glmm_b) # elevation is ~7.4, elevation is ~3.2, elevation:test is ~8.6

### Summary output for GLMM on local enhancement ####
summary(perch_glmm_b)# Variable "testSoc" is significant in the model with a positive estimate. This suggest observers were significantly more likely to perch than control individuals. 



## Repeatability of local enhancement ####
# Only observers
rep_perch<-rptBinary(perched~task.n+elev.+mean_movements_sc+seas_days_sc+(1|obs.ID),grname = c("obs.ID", "Fixed"), data=slearn_obs, CI=0.95, nboot=1000)
  # Model for partial R for elevation:
rep_perch_elev<-rptBinary(perched~elev.+(1|obs.ID),grname = c("obs.ID", "Fixed"), data=slearn_obs, CI=0.95, nboot=1000)


### Summary for repeatability of local enhancement ####
# Only observers
rep_perch # full
rep_perch_elev #only elevation
summary(rep_perch)
plot(rep_perch, grname = "obs.ID", type = "boot") #plot bootstrapping output and R estimation


## Survival analysis Local enhancement ####
### Mixed effect cox model for local enhancement
# Observers only
surv_perch<- coxme(Surv(lat_perch, perched)~ elev.+task.n+mean_movements_sc+seas_days_sc+sex+age_adjust+(1|obs.ID), data = slearn_obs)

### Model diagnostics - Local enhancement survival model
# Creating frailty model (qualitatively not different from the coxme model) to test assumptions regarding influential observations, linearity and outliers.
# Observers only
surv_perch_fr<- coxph(Surv(lat_perch, perched)~ elev.+task.n+mean_movements_sc+seas_days_sc+sex+age_adjust+frailty(obs.ID), data = slearn_obs)

#### Linearity between continuous predictors and log-hazard of the model (tested on the frailty model using martingale residuals)
# Observers only
resid_surv_perch_fr <- residuals(surv_perch_fr, type = "martingale")
resid_surv_perch_fr # residual for row 48 not included, This is adjusted in the matrix created for the residual plots below.
AC <- as.matrix(slearn_obs[, c("mean_movements_sc", "seas_days_sc")])
for (j in 1:2) {
  plot(AC[-c(48), j],
       resid_surv_perch_fr,
       xlab = c("activity", "days")[j],
       ylab = "residuals")
  abline(h = 0, lty = 2)
  lines(lowess(AC[-c(48), j], resid_surv_perch_fr, iter = 0))
} # OK

#### Influential observations (tested on the frailty model)
# Observers only
ggcoxdiagnostics(surv_perch_fr, type = "dfbetas", linear.predictions = FALSE, ggtheme=theme_bw()) #no values goes outside +/- 1 so there are no particular influential observations.

#### Checking for outliers (tested on the frailty model)
# Observers only
pred_lp_fr_perch <-
  predict(surv_perch_fr, type = "lp") # for plot of log-odds residuals
pred_Surv_fr_perch <-
  exp(-predict(surv_perch_fr, type = "expected")) # for plot of normal-deviate residuals
# Plot to view outliers
lgo.res <- log(pred_Surv_fr_perch / (1 - pred_Surv_fr_perch))
nd.res <- qnorm(pred_Surv_fr_perch)
lgo.res <- data.frame(lgo.res = lgo.res, lp = pred_lp_fr_perch)
nd.res <- data.frame(nd.res = nd.res, lp = pred_lp_fr_perch)
lgoPlot <-
  ggplot(lgo.res, aes(x = pred_lp_fr_perch, y = lgo.res)) + geom_point(size = I(0.3)) + xlab("Linear Predictions") + ylab("Log-odds Residual") + geom_hline(lty = 2,
                                                                                                                                                            col = "red",
                                                                                                                                                            yintercept = c(3.66, -3.66))
ndPlot <-
  ggplot(nd.res, aes(x = pred_lp_fr_perch, y = nd.res)) + geom_point(size = I(0.3)) + xlab("Linear Predictions") + ylab("Normal Deviate Residual") + geom_hline(lty = 2,
                                                                                                                                                                col = "red",
                                                                                                                                                                yintercept = c(1.96, -1.96))
grid.arrange(lgoPlot, ndPlot, ncol = 2) # No outliers

#### Proportional Hazards (PH) assumption for the Cox mixed-effects model
# Observers only
cox.zph(surv_perch) # no variable is significant -> model fulfill the assumption

#### Multicollinearity
# Observers only
# Testing multicollinearity with the Variance Inflation Factor test (VIF). 
rms::vif(surv_perch) # OK

### Summary of Survival: Local Enhancement ####
# Observers only
summary(surv_perch)


# Visualize survival plots perching behaviour
### Plots are formatted to be combined like Fig 4 in the article
### Code to combine all survival plots and present them as in Fig 4 of the article is given at the end of this code script

#### Perching behaviour in the colour discrimination task
#Creating survival plots for perching behaviour for the Colour task and lines representing high and low elevation groups.


surv_perch_plot1 <-
  survfit(
    Surv(lat_perch[slearn_obs$task == "pom"], perched[slearn_obs$task == "pom"]) ~
      elev.[slearn_obs$task == "pom"],
    data = slearn_obs,
    conf.type = "plain",
    conf.int = 0.95
  )
ggsurv_perch_pom <-
  ggsurvplot(
    surv_perch_plot1,
    data = slearn_obs,
    conf.int = TRUE,
    size = 1,
    surv.scale = "default",
    palette = "lancet",
    xlab = "",
    ylab = "Proportion of birds yet to\n perch",
    legend = "none"
  )
ggsurv_perch_pom$plot <-
  ggsurv_perch_pom$plot + labs(title = "Colour", tag = "A") + theme(
    plot.title = element_text(hjust = 0.5, face = "bold", size = 12),
    plot.tag.position = c(0.27, 0.2),
    plot.tag = element_text(size = 14, face = "bold"),
    axis.text.x = element_blank(),
    plot.margin = unit(c(0, -0.2, 0, 0), "cm"),
    axis.title.y = element_text(size = 12)
  ) + scale_x_continuous(breaks = seq(0, 1505, 301)) + theme(panel.grid.major.x = element_line(colour =
                                                                                                 "lightgrey", size = 0.5))
ggsurv_perch_pom


#### Perching behaviour in the spatial learning task
#Creating survival plots for perching behaviour for the Spatial task and lines representing high and low elevation groups.


surv_perch_plot2 <-
  survfit(
    Surv(lat_perch[slearn_obs$task == "leaf"], perched[slearn_obs$task == "leaf"]) ~
      elev.[slearn_obs$task == "leaf"],
    data = slearn_obs,
    conf.type = "plain",
    conf.int = 0.95
  )
ggsurv_perch_leaf <-
  ggsurvplot(
    surv_perch_plot2,
    data = slearn_obs,
    conf.int = TRUE,
    size = 1,
    break.x.by = 301,
    xlim = c(0, 1505),
    palette = "lancet",
    xlab = "",
    ylab = "",
    legend = "none",
    title = "Spatial"
  )
ggsurv_perch_leaf$plot <-
  ggsurv_perch_leaf$plot + labs(title = "Spatial", tag = "B") + theme(
    plot.title = element_text(hjust = 0.5, face = "bold", size = 12),
    plot.tag.position = c(0.15, 0.2),
    plot.tag = element_text(size = 14, face = "bold"),
    axis.text.x = element_blank(),
    axis.text.y = element_blank(),
    plot.margin = unit(c(0, -0.2, 0, 0), "cm")
  ) + scale_x_continuous(breaks = seq(0, 1505, 301)) + theme(panel.grid.major.x = element_line(colour =
                                                                                                 "lightgrey", size = 0.5))
ggsurv_perch_leaf













####
# Action copying ####
## GLMM of sampling ####
# Negative Binomial generalized linear mixed effects model
samp_glmm_nb<- glmer.nb(tot.samps~elev.*test+task.n+mean_movements_sc+seas_days_sc+sex+age_adjust+(1|obs.ID), data = slearn_all) # Warning: Model is nearly unidentifiable

### Model diagnostics
#### Residuals vs fitted
# Observers and Control: elevation*test (negative binomial)
sim.diag_samp_glmm_nb<-simulateResiduals(fittedModel = samp_glmm_nb, n = 1000) #data simulated 1000 times based on model input
plot(sim.diag_samp_glmm_nb) # OK

#### Overdispersion test
# Observers and Control: elevation*test (negative binomial)
testDispersion(sim.diag_samp_glmm_nb)# Overdispersion with DHARMa package. Non-sig-> no indication of overdispersion

#### zero-inflation test
# Observers and Control: elevation*test (negative binomial)
testZeroInflation(sim.diag_samp_glmm_nb) #non-sig -> no indication of zero inflation

### Summary of sampling GLMM output ####
# Observers and Control: elevation*test (negative binomial)
summary(samp_glmm_nb) # Warnings about the variance-covariance matrix. 



## Repeatability of total number of items sampled ####
# Observers only
rep_tot_samp_obs<-rptPoisson(tot.samps~task.n+elev.+mean_movements_sc+seas_days_sc+(1|obs.ID),grname = c("obs.ID","Fixed"), data=slearn_obs, CI=0.95, nboot=1000) # Many iterations give message about model being singular fit. Output qualitatively the same as m1. No rptR test available for negative binomial.
  # Model for partial R for elevation:
rep_tot_samp_obs_elev<-rptPoisson(tot.samps~elev.+(1|obs.ID),grname = c("obs.ID","Fixed"), data=slearn_obs, CI=0.95, nboot=1000)

### Summary for repeatability of Action copying ####
# # Observers only
rep_tot_samp_obs #full
rep_tot_samp_obs_elev # only elevation
plot(rep_tot_samp_obs, grname = "obs.ID", type = "boot")



## Survival analysis Action copying ####
### Mixed effect cox model for action copying
# # Observers only
surv_samp_obs<- coxme(Surv(lat_samp, sampled)~ elev.+task.n+mean_movements_sc+seas_days_sc+sex+age_adjust+(1|obs.ID), data = slearn_obs)

### Model diagnostics - Action copying survival model
# Creating frailty model (qualitatively not different from the coxme model) to test assumptions regarding influential observations, linearity and outliers.
# # Observers only 
surv_samp_obs_fr<- coxph(Surv(lat_samp, sampled)~ elev.+task.n+mean_movements_sc+seas_days_sc+sex+age_adjust+frailty(obs.ID), data = slearn_obs)

#### Linearity between continuous predictors and log-hazard of the model (tested on the frailty model using martingale residuals)
#Linearity check on the coxph sampling frailty model
# Observers only
resid_surv_samp_obs_fr <-
  residuals(surv_samp_obs_fr, type = "martingale", na.exclude = FALSE)
length(resid_surv_samp_obs_fr) #77 # 3 observations deleted due to missingness in the model. There are no entry 42,48,49.
ABC <- as.matrix(slearn_obs[, c("mean_movements_sc", "seas_days_sc")])
for (j in 1:2) {
  plot(
    ABC[-c(42, 48, 49), j],
    resid_surv_samp_obs_fr,
    xlab = c("activity", "days")[j],
    ylab = "residuals"
  )
  abline(h = 0, lty = 2) +
    lines(lowess(ABC[-c(42, 48, 49), j], resid_surv_samp_obs_fr, iter = 0))
} # OK

#### Influential observations (tested on the frailty model)
# # Observers only
ggcoxdiagnostics(surv_samp_obs_fr, type = "dfbetas", linear.predictions = FALSE, ggtheme=theme_bw()) #no values goes outside +/- 1 so there are no particular influential observations.

#### Checking for outliers (tested on the frailty model)
# # Observers
pred_lp_obs_samp <-
  predict(surv_samp_obs_fr, type = "lp") # for plot of log-odds residuals
pred_Surv_obs_samp <-
  exp(-predict(surv_samp_obs_fr, type = "expected")) # for plot of normal-deviate residuals
# Plot to view outliers
lgo.res <- log(pred_Surv_obs_samp / (1 - pred_Surv_obs_samp))
nd.res <- qnorm(pred_Surv_obs_samp)
lgo.res <- data.frame(lgo.res = lgo.res, lp = pred_lp_obs_samp)
nd.res <- data.frame(nd.res = nd.res, lp = pred_lp_obs_samp)
lgoPlot <-
  ggplot(lgo.res, aes(x = pred_lp_obs_samp, y = lgo.res)) + geom_point(size = I(0.3)) + xlab("Linear Predictions") + ylab("Log-odds Residual") + geom_hline(lty = 2,
                                                                                                                                                            col = "red",
                                                                                                                                                            yintercept = c(3.66, -3.66))
ndPlot <-
  ggplot(nd.res, aes(x = pred_lp_obs_samp, y = nd.res)) + geom_point(size = I(0.3)) + xlab("Linear Predictions") + ylab("Normal Deviate Residual") + geom_hline(lty = 2,
                                                                                                                                                                col = "red",
                                                                                                                                                                yintercept = c(1.96, -1.96))
grid.arrange(lgoPlot, ndPlot, ncol = 2) # No outliers detected

#### Proportional Hazards (PH) assumption for the mixed-effects survival model
# Observers only
cox.zph(surv_samp_obs) # No variable is significant -> model fulfill the assumption

#### Multicollinearity
# Testing multicollinearity with the Variance Inflation Factor test (VIF).
# Observers only
rms::vif(surv_samp_obs) #no values above 5, no indication of variance inflation (no multicollinearity)

###### Summary output for mixed effects survival model for action copying ####
# Observers only
summary(surv_samp_obs)



# Visualize survival plots perching behaviour
### Plots are formatted to be combined like Fig 4 in the article

#### Sampling behaviour in the colour discrimination task task
#Creating survival plots for sampling behaviour for the Colour task and lines representing high and low elevation groups.


surv_sampling_plot1 <-
  survfit(
    Surv(lat_samp[slearn_obs$task == "pom"], sampled[slearn_obs$task == "pom"]) ~
      elev.[slearn_obs$task == "pom"],
    data = slearn_obs,
    conf.type = "plain",
    conf.int = 0.95
  )
ggsurv_sampling_pom <-
  ggsurvplot(
    surv_sampling_plot1,
    data = slearn_obs,
    conf.int = TRUE,
    size = 1,
    surv.scale = "default",
    xlab = "Trial Number",
    palette = "lancet",
    ylab = "Proportion of birds yet to\n sample",
    legend = c(0.2, 0.4),
    legend.title = "Elevation",
    legend.labs = c("High", "Low")
  )

ggsurv_sampling_pom$plot <- ggsurv_sampling_pom$plot +
  labs(tag = "C") + theme(
    plot.tag.position = c(0.27, 0.25),
    plot.tag = element_text(size = 14, face = "bold"),
    plot.margin = unit(c(0, -0.2, 0, 0), "cm"),
    axis.title.y = element_text(size = 12)
  ) +
  scale_x_continuous(breaks = seq(0, 1505, 301),
                     labels = c("", "1", "2", "3", "4", "5")) +
  theme(
    panel.grid.major.x = element_line(colour = "lightgrey", size = 0.5),
    axis.text.x = element_text(hjust = 4, size = 10),
    axis.title.x = element_text(size = 12, vjust = 0.1),
    axis.text.y = element_text(size = 12)
  )
ggsurv_sampling_pom

#### Sampling in leaf task
#Creating survival plots for sampling behaviour for the Spatial task and lines representing high and low elevation groups.


surv_sampling_plot2 <-
  survfit(
    Surv(lat_samp[slearn_obs$task == "leaf"], sampled[slearn_obs$task == "leaf"]) ~
      elev.[slearn_obs$task == "leaf"],
    data = slearn_obs,
    conf.type = "plain",
    conf.int = 0.95
  )
ggsurv_sampling_leaf <-
  ggsurvplot(
    surv_sampling_plot2,
    data = slearn_obs,
    conf.int = TRUE,
    size = 1,
    surv.scale = "default",
    palette = "lancet",
    xlab = "Trial Number",
    ylab = "",
    legend = "none"
  )

ggsurv_sampling_leaf$plot <- ggsurv_sampling_leaf$plot +
  labs(tag = "D") + theme(
    plot.tag.position = c(0.15, 0.25),
    plot.tag = element_text(size = 14, face = "bold"),
    axis.text.y = element_blank(),
    plot.margin = unit(c(0, -0.2, 0, 0), "cm"),
    axis.title.y = element_text(size = 12)
  ) +
  scale_x_continuous(breaks = seq(0, 1505, 301),
                     labels = c("", "1", "2", "3", "4", "5")) +
  theme(
    panel.grid.major.x = element_line(colour = "lightgrey", size = 0.5),
    axis.text.x = element_text(
      hjust = 4,
      size = 10,
      vjust = -0.1
    ),
    axis.title.x = element_text(size = 12, vjust = 0.1)
  )
ggsurv_sampling_leaf


# MS: Figure 3 ####
samp_fig <-  slearn_all%>%mutate(elev_test= paste0(elev.," / ", test),
                                 elev_test= if_else(elev_test=="high / Cont", "High - Control", if_else(elev_test=="high / Soc", "High - Observer", if_else(elev_test=="low / Cont", "Low - Control", "Low - Observer"))))
fig3_xlabels <- C("High -\n Control", "High -\n Observer", "Low -\n Control", "Low -\n Observer")

pom_samp_fig <- samp_fig%>%filter(task=="pom")%>%
  ggplot(aes(x=elev_test, y= tot.samps))+
  geom_boxplot(fill="grey")+
  ylab("Number of items sampled")+
  xlab("Elevation - Test group")+
  labs(title = "Colour")+
  theme_classic2()+
  scale_y_continuous(limits = c(0,6.4), breaks = c(0,2,4,6), expand = expansion(add = 0.1))+
  scale_x_discrete(labels=c("High -\n Control", "High -\n Observer", "Low -\n Control", "Low -\n Observer"))+
  theme(axis.text = element_text(size = 10),
        axis.title = element_text(size = 12),
        plot.title = element_text(size = 14, face = "bold", hjust = 0.5))#+
  # annotate("text", x=2.5, y=6.3, label="Colour", fontface=2, size=5)


leaf_samp_fig <- samp_fig%>%filter(task=="leaf")%>%
  ggplot(aes(x=elev_test, y= tot.samps))+
  geom_boxplot(fill="grey")+
  ylab(NULL)+
  xlab("Elevation - Test group")+
  labs(title = "Spatial")+
  scale_y_continuous(limits = c(0,6.4), breaks = c(0,2,4,6), expand = expansion(add = 0.1))+
  scale_x_discrete(labels=c("High -\n Control", "High -\n Observer", "Low -\n Control", "Low -\n Observer"))+
  theme_classic2()+
  theme(axis.text.y = element_blank(),
        axis.text = element_text(size = 10),
        axis.title = element_text(size = 12),
        plot.title = element_text(size = 14, face = "bold", hjust = 0.5)) #+
  # annotate("text", x=2.5, y=6.3, label="Spatial", fontface=2, size=5)

fig3 <- ggarrange(pom_samp_fig,leaf_samp_fig)
ggsave("elev_test_sampling.png", plot = fig3, units = "cm", width = 17, height = 13, dpi=300)


# MS: Table 3 GLMM outputs ####
tab_model(
  perch_glmm_b,
  samp_glmm_nb,
  transform = NULL,
  show.ci = F,
  show.se = T,
  string.est = "Estimate",
  string.se = "SE",
  string.stat = "z-value",
  pred.labels = c(
    `(Intercept)` = "Intercept",
    `elev.low` = "Elevation (Low)",
    `testSoc` = "Test (Observer)",
    `task.n` = "Task (Spatial)",
    `mean_movements_sc` = "Activity",
    `seas_days_sc` = "Days into season",
    `sexM` = "Sex (Male)",
    `age_adjust1a` = "Age (Juvenile)",
    `elev.low:testSoc` = "Elevation (Low) * Test (Observer)"
  ),
  dv.labels = c(
    "Local Enhancement: Binomial GLMM",
    "Action Copying: Negative Binomial GLMM"
  ),
  show.re.var = T,
  show.ngroups = F,
  show.icc = F,
  show.obs = F,
  show.r2 = F,
  show.stat = T,
  digits.p = 2,
  file = "./elev_slearn_GLMM_summaries.doc"
)

# MS: Table 4 Coxme outputs ####
tab_model(
  surv_perch,
  surv_samp_obs,
  transform = "exp",
  show.ci = F,
  std.response = TRUE ,
  show.se = T,
  string.est = "Hazard ratio",
  string.se = "SE",
  string.stat = "z-value",
  pred.labels = c(
    `(Intercept)` = "Intercept",
    `elev.low` = "Elevation (Low)",
    `task.n` = "Task (Spatial)",
    `mean_movements_sc` = "Activity",
    `seas_days_sc` = "Days into season",
    `sexM` = "Sex (Male)",
    `age_adjust1a` = "Age (Juvenile)"
  ),
  dv.labels = c("Local Enhancement", "Action Copying"),
  show.re.var = T,
  show.ngroups = F,
  show.icc = F,
  show.obs = F,
  show.r2 = F,
  show.stat = T,
  digits.p = 2,
  file = "./elev_slearn_survival_summaries.doc"
) # tab_model can only include either log(hazard) or hazard ratio in the table, the other is entered manually. 


# MS: Fig 4. Survival plots ####
surv_plots <- list() #empty list to fill with survival plots 
surv_plots[[1]] <- ggsurv_perch_pom #perching in pompom task
surv_plots[[3]] <- ggsurv_perch_leaf #sampling in pompom task
surv_plots[[2]] <- ggsurv_sampling_pom # perching in leaf task
surv_plots[[4]] <- ggsurv_sampling_leaf #sampling in leaf task

panex4_surv<- arrange_ggsurvplots(surv_plots, ncol=2, nrow=2)
panex4_surv
ggsave("panex4_surv.png", plot = panex4_surv, units = "cm", width = 17, height = 13, dpi=300)
